@@ -10,7 +10,6 @@ from pytype.abstract import _classes
 from pytype.abstract import _function_base
 from pytype.abstract import _instance_base
 from pytype.abstract import _instances
-from pytype.abstract import _singletons
 from pytype.abstract import _typing
 from pytype.abstract import abstract_utils
 from pytype.abstract import class_mixin
@@ -76,266 +75,7 @@ def _check_classes(var, check):
   return True
 
 
-class SignedFunction(_function_base.Function):
-  """An abstract base class for functions represented by function.Signature.
-
-  Subclasses should define call(self, node, f, args) and set self.bound_class.
-  """
-
-  def __init__(self, signature, ctx):
-    super().__init__(signature.name, ctx)
-    self.signature = signature
-    # Track whether we've annotated `self` with `set_self_annot`, since
-    # annotating `self` in `__init__` is otherwise illegal.
-    self._has_self_annot = False
-
-  @contextlib.contextmanager
-  def set_self_annot(self, annot_class):
-    """Set the annotation for `self` in a class."""
-    self_name = self.signature.param_names[0]
-    old_self = self.signature.annotations.get(self_name)
-    old_has_self_annot = self._has_self_annot
-    self.signature.annotations[self_name] = annot_class
-    self._has_self_annot = True
-    try:
-      yield
-    finally:
-      if old_self:
-        self.signature.annotations[self_name] = old_self
-      else:
-        del self.signature.annotations[self_name]
-      self._has_self_annot = old_has_self_annot
-
-  def argcount(self, _):
-    return len(self.signature.param_names)
-
-  def get_nondefault_params(self):
-    return ((n, n in self.signature.kwonly_params)
-            for n in self.signature.param_names
-            if n not in self.signature.defaults)
-
-  def match_and_map_args(self, node, args, alias_map):
-    """Calls match_args() and _map_args()."""
-    return self.match_args(node, args, alias_map), self._map_args(node, args)
-
-  def _map_args(self, node, args):
-    """Map call args to function args.
-
-    This emulates how Python would map arguments of function calls. It takes
-    care of keyword parameters, default parameters, and *args and **kwargs.
-
-    Args:
-      node: The current CFG node.
-      args: The arguments.
-
-    Returns:
-      A dictionary, mapping strings (parameter names) to cfg.Variable.
-
-    Raises:
-      function.FailedFunctionCall: If the caller supplied incorrect arguments.
-    """
-    # Originate a new variable for each argument and call.
-    posargs = [u.AssignToNewVariable(node)
-               for u in args.posargs]
-    kws = {k: u.AssignToNewVariable(node)
-           for k, u in args.namedargs.items()}
-    sig = self.signature
-    callargs = {
-        name: self.ctx.program.NewVariable(default.data, [], node)
-        for name, default in sig.defaults.items()
-    }
-    positional = dict(zip(sig.param_names, posargs))
-    posonly_names = set(sig.posonly_params)
-    for key in set(positional) - posonly_names:
-      if key in kws:
-        raise function.DuplicateKeyword(sig, args, self.ctx, key)
-    kwnames = set(kws)
-    extra_kws = kwnames.difference(sig.param_names + sig.kwonly_params)
-    if extra_kws and not sig.kwargs_name:
-      if function.has_visible_namedarg(node, args, extra_kws):
-        raise function.WrongKeywordArgs(sig, args, self.ctx, extra_kws)
-    posonly_kws = kwnames & posonly_names
-    # If a function has a **kwargs parameter, then keyword arguments with the
-    # same name as a positional-only argument are allowed, e.g.:
-    #   def f(x, /, **kwargs): ...
-    #   f(0, x=1)  # ok
-    if posonly_kws and not sig.kwargs_name:
-      raise function.WrongKeywordArgs(sig, args, self.ctx, posonly_kws)
-    callargs.update(positional)
-    callargs.update(kws)
-    for key, kwonly in self.get_nondefault_params():
-      if key not in callargs:
-        if args.starstarargs or (args.starargs and not kwonly):
-          # We assume that because we have *args or **kwargs, we can use these
-          # to fill in any parameters we might be missing.
-          callargs[key] = self.ctx.new_unsolvable(node)
-        else:
-          raise function.MissingParameter(sig, args, self.ctx, key)
-    for key in sig.kwonly_params:
-      if key not in callargs:
-        raise function.MissingParameter(sig, args, self.ctx, key)
-    if sig.varargs_name:
-      varargs_name = sig.varargs_name
-      extraneous = posargs[self.argcount(node):]
-      if args.starargs:
-        if extraneous:
-          log.warning("Not adding extra params to *%s", varargs_name)
-        callargs[varargs_name] = args.starargs.AssignToNewVariable(node)
-      else:
-        callargs[varargs_name] = self.ctx.convert.build_tuple(node, extraneous)
-    elif len(posargs) > self.argcount(node):
-      raise function.WrongArgCount(sig, args, self.ctx)
-    if sig.kwargs_name:
-      kwargs_name = sig.kwargs_name
-      # Build a **kwargs dictionary out of the extraneous parameters
-      if args.starstarargs:
-        callargs[kwargs_name] = args.starstarargs.AssignToNewVariable(node)
-      else:
-        omit = sig.param_names + sig.kwonly_params
-        k = _instances.Dict(self.ctx)
-        k.update(node, args.namedargs, omit=omit)
-        callargs[kwargs_name] = k.to_variable(node)
-    return callargs
-
-  def _match_args_sequentially(self, node, args, alias_map, match_all_views):
-    args_to_match = []
-    for name, arg, formal in self.signature.iter_args(args):
-      if formal is None:
-        continue
-      if name in (self.signature.varargs_name, self.signature.kwargs_name):
-        # The annotation is Tuple or Dict, but the passed arg only has to be
-        # Iterable or Mapping.
-        formal = self.ctx.convert.widen_type(formal)
-      args_to_match.append(function.Arg(name, arg, formal))
-    matcher = self.ctx.matcher(node)
-    try:
-      matches = matcher.compute_matches(
-          args_to_match, match_all_views, alias_map=alias_map)
-    except matcher.MatchError as e:
-      raise function.WrongArgTypes(self.signature, args, self.ctx, e.bad_type)
-    return [m.subst for m in matches]
-
-  def get_first_opcode(self):
-    return None
-
-  def set_function_defaults(self, node, defaults_var):
-    """Attempts to set default arguments of a function.
-
-    If defaults_var is not an unambiguous tuple (i.e. one that can be processed
-    by abstract_utils.get_atomic_python_constant), every argument is made
-    optional and a warning is issued. This function emulates __defaults__.
-
-    Args:
-      node: The node where default arguments are being set. Needed if we cannot
-            get a useful value from defaults_var.
-      defaults_var: a Variable with a single binding to a tuple of default
-                    values.
-    """
-    defaults = self._extract_defaults(defaults_var)
-    if defaults is None:
-      defaults = [
-          self.ctx.new_unsolvable(node) for _ in self.signature.param_names
-      ]
-    defaults = dict(zip(self.signature.param_names[-len(defaults):], defaults))
-    self.signature.defaults = defaults
-
-  def _mutations_generator(self, node, first_arg, substs):
-    def generator():
-      """Yields mutations."""
-      if (not (self.is_attribute_of_class or self.name == "__new__") or
-          not first_arg or not substs):
-        return
-      try:
-        inst = abstract_utils.get_atomic_value(
-            first_arg, _instance_base.Instance)
-      except abstract_utils.ConversionError:
-        return
-      if inst.cls.template:
-        for subst in substs:
-          for k, v in subst.items():
-            if k in inst.instance_type_parameters:
-              value = inst.instance_type_parameters[k].AssignToNewVariable(node)
-              if all(isinstance(val, _singletons.Unknown) for val in v.data):
-                for param in inst.cls.template:
-                  if subst.same_name(k, param.full_name):
-                    value.PasteVariable(param.instantiate(node), node)
-                    break
-                else:
-                  # See GenericFeatureTest.test_reinherit_generic in
-                  # tests/test_generic2. This can happen if one generic class
-                  # inherits from another and separately reuses a TypeVar.
-                  value.PasteVariable(v, node)
-              else:
-                value.PasteVariable(v, node)
-              yield function.Mutation(inst, k, value)
-    # Optimization: return a generator to avoid iterating over the mutations an
-    # extra time.
-    return generator
-
-
-class SimpleFunction(SignedFunction):
-  """An abstract value representing a function with a particular signature.
-
-  Unlike InterpreterFunction, a SimpleFunction has a set signature and does not
-  record calls or try to infer types.
-  """
-
-  def __init__(self, signature, ctx):
-    super().__init__(signature, ctx)
-    self.bound_class = _function_base.BoundFunction
-
-  @classmethod
-  def build(cls, name, param_names, posonly_count, varargs_name, kwonly_params,
-            kwargs_name, defaults, annotations, ctx):
-    """Returns a SimpleFunction.
-
-    Args:
-      name: Name of the function as a string
-      param_names: Tuple of parameter names as strings. This DOES include
-        positional-only parameters and does NOT include keyword-only parameters.
-      posonly_count: Number of positional-only parameters.
-      varargs_name: The "args" in "*args". String or None.
-      kwonly_params: Tuple of keyword-only parameters as strings.
-      kwargs_name: The "kwargs" in "**kwargs". String or None.
-      defaults: Dictionary of string names to values of default arguments.
-      annotations: Dictionary of string names to annotations (strings or types).
-      ctx: The abstract context for this function.
-    """
-    annotations = dict(annotations)
-    # Every parameter must have an annotation. Defaults to unsolvable.
-    for n in itertools.chain(param_names, [varargs_name, kwargs_name],
-                             kwonly_params):
-      if n and n not in annotations:
-        annotations[n] = ctx.convert.unsolvable
-    if not isinstance(defaults, dict):
-      defaults = dict(zip(param_names[-len(defaults):], defaults))
-    signature = function.Signature(name, param_names, posonly_count,
-                                   varargs_name, kwonly_params, kwargs_name,
-                                   defaults, annotations)
-    return cls(signature, ctx)
-
-  def call(self, node, _, args, alias_map=None):
-    args = args.simplify(node, self.ctx)
-    callargs = self._map_args(node, args)
-    substs = self.match_args(node, args, alias_map)
-    # Substitute type parameters in the signature's annotations.
-    annotations = self.ctx.annotation_utils.sub_annotations(
-        node, self.signature.annotations, substs, instantiate_unbound=False)
-    if self.signature.has_return_annotation:
-      ret_type = annotations["return"]
-      ret = ret_type.instantiate(node)
-    else:
-      ret = self.ctx.convert.none.to_variable(node)
-    if self.name == "__new__":
-      self_arg = ret
-    else:
-      self_arg = self.signature.get_self_arg(callargs)
-    mutations = self._mutations_generator(node, self_arg, substs)
-    node = abstract_utils.apply_mutations(node, mutations)
-    return node, ret
-
-
-class InterpreterFunction(SignedFunction):
+class InterpreterFunction(_function_base.SignedFunction):
   """An abstract value representing a user-defined function.
 
   Attributes:
