@@ -236,7 +236,7 @@ _OPT_IN_FEATURES = [
 FEATURE_FLAGS = [
     _flag("--always-use-return-annotations", False,
           "Always use function return type annotations."),
-    _flag("--mapping-is-not-sequence", False,
+    _flag("--mapping-is-not-sequence", True,
           "Do not treat Mapping as satisfying the Sequence protocol."),
     _flag("--overriding-default-value-checks", False,
           "Enable default value checks for overriding methods."),
