@@ -456,8 +456,8 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
               pytd.NamedType("builtins.type"), (pytd.NamedType(n),))
         # We convert known special forms to their corresponding types and
         # otherwise treat them as unknown types.
-        if name == "Protocol":
-          typ = type_of("typing.Protocol")
+        if name in {"Final", "Protocol", "TypeGuard"}:
+          typ = type_of(f"typing.{name}")
         elif name == "LiteralString":
           typ = type_of("builtins.str")
         else:
