@@ -262,7 +262,6 @@ class Frame(utils.ContextWeakrefMixin):
     # The first argument is used to make Python 3 super calls when super is not
     # passed any arguments.
     self.first_arg = first_arg
-    self.cells = {}
 
     self.allowed_returns = None
     self.check_return = False
@@ -327,6 +326,13 @@ class Frame(utils.ContextWeakrefMixin):
   def type_params(self):
     return set(itertools.chain.from_iterable(self.substs))
 
+  def lookup_name(self, target_name):
+    for store in (self.f_locals, self.f_globals, self.f_builtins):
+      if target_name in store.members:
+        return store.members[target_name]
+    i = (self.f_code.co_cellvars + self.f_code.co_freevars).index(target_name)
+    return self.cells[i]
+
 
 class Condition:
   """Represents a condition due to if-splitting.
