@@ -1,16 +1,15 @@
 """Use pytype to analyze and infer types for an entire project."""
 
 import logging
-import os
 import subprocess
 import sys
 from typing import Iterable, Sequence, Tuple
 
 from pytype import file_utils
 from pytype import module_utils
+from pytype.platform_utils import path_utils
 from pytype.tools.analyze_project import config
 
-
 # Generate a default pyi for builtin and system dependencies.
 DEFAULT_PYI = """
 from typing import Any
@@ -36,11 +35,14 @@ FIRST_PASS_SUFFIX = '-1'
 def _get_executable(binary, module=None):
   """Get the path to the executable with the given name."""
   if binary == 'pytype-single':
-    custom_bin = os.path.join('out', 'bin', 'pytype')
+    custom_bin = path_utils.join('out', 'bin', 'pytype')
     if sys.argv[0] == custom_bin:
       # The Travis type-check step uses custom binaries in pytype/out/bin/.
-      return [os.path.join(os.path.abspath(os.path.dirname(custom_bin)),
-                           'pytype-single')]
+      return (([] if sys.platform != 'win32' else [sys.executable]) + [
+          path_utils.join(
+              path_utils.abspath(path_utils.dirname(custom_bin)),
+              'pytype-single')
+      ])
   if sys.executable is not None:
     return [sys.executable, '-m', module or binary]
   else:
@@ -55,7 +57,7 @@ def resolved_file_to_module(f):
   path = full_path[:-len(target)]
   name = f.module_name
   # We want to preserve __init__ in the module_name for pytype.
-  if os.path.basename(full_path) == '__init__.py':
+  if path_utils.basename(full_path) == '__init__.py':
     name += '.__init__'
   return module_utils.Module(
       path=path, target=target, name=name, kind=f.__class__.__name__)
@@ -101,14 +103,14 @@ def deps_from_import_graph(import_graph):
 
 
 def _is_type_stub(f):
-  _, ext = os.path.splitext(f)
+  _, ext = path_utils.splitext(f)
   return ext in ('.pyi', '.pytd')
 
 
 def _module_to_output_path(mod):
   """Convert a module to an output path."""
-  path, _ = os.path.splitext(mod.target)
-  if path.replace(os.path.sep, '.').endswith(mod.name):
+  path, _ = path_utils.splitext(mod.target)
+  if path.replace(path_utils.sep, '.').endswith(mod.name):
     # Preferentially use the short path.
     return path[-len(mod.name):]
   else:
@@ -117,7 +119,23 @@ def _module_to_output_path(mod):
     # python packages anyway, we preserve any leading '.' in order to not
     # create a file directly in / (which would likely cause a crash with a
     # permission error) and let the rest of the path be mangled.
-    return mod.name[0] + mod.name[1:].replace('.', os.path.sep)
+    return mod.name[0] + mod.name[1:].replace('.', path_utils.sep)
+
+
+def escape_ninja_path(path: str):
+  """escape `:` in absolute path on windows."""
+  if sys.platform == 'win32':
+    new_path = ''
+    last_char = None
+    for ch in path:
+      if last_char != '$' and ch == ':':
+        new_path += '$:'
+      else:
+        new_path += ch
+      last_char = ch
+    return new_path
+  else:
+    return path
 
 
 def get_imports_map(deps, module_to_imports_map, module_to_output):
@@ -139,9 +157,9 @@ class PytypeRunner:
     self.sorted_sources = sorted_sources
     self.python_version = conf.python_version
     self.platform = conf.platform
-    self.pyi_dir = os.path.join(conf.output, 'pyi')
-    self.imports_dir = os.path.join(conf.output, 'imports')
-    self.ninja_file = os.path.join(conf.output, 'build.ninja')
+    self.pyi_dir = path_utils.join(conf.output, 'pyi')
+    self.imports_dir = path_utils.join(conf.output, 'imports')
+    self.ninja_file = path_utils.join(conf.output, 'build.ninja')
     self.custom_options = [
         (k, getattr(conf, k)) for k in set(conf.__slots__) - set(config.ITEMS)]
     self.keep_going = conf.keep_going
@@ -197,14 +215,15 @@ class PytypeRunner:
 
   def write_default_pyi(self):
     """Write a default pyi file."""
-    output = os.path.join(self.imports_dir, 'default.pyi')
+    output = path_utils.join(self.imports_dir, 'default.pyi')
     with open(output, 'w') as f:
       f.write(DEFAULT_PYI)
     return output
 
   def write_imports(self, module_name, imports_map, suffix):
     """Write a .imports file."""
-    output = os.path.join(self.imports_dir, module_name + '.imports' + suffix)
+    output = path_utils.join(self.imports_dir,
+                             module_name + '.imports' + suffix)
     with open(output, 'w') as f:
       for item in imports_map.items():
         f.write('%s %s\n' % item)
@@ -291,19 +310,23 @@ class PytypeRunner:
     Returns:
       The expected output of the build statement.
     """
-    output = os.path.join(self.pyi_dir,
-                          _module_to_output_path(module) + '.pyi' + suffix)
+    output = path_utils.join(self.pyi_dir,
+                             _module_to_output_path(module) + '.pyi' + suffix)
     logging.info('%s %s\n  imports: %s\n  deps: %s\n  output: %s',
                  action, module.name, imports, deps, output)
+    if deps:
+      deps = ' | ' +  escape_ninja_path(' '.join(deps))
+    else:
+      deps = ''
     with open(self.ninja_file, 'a') as f:
       f.write('build {output}: {action} {input}{deps}\n'
               '  imports = {imports}\n'
               '  module = {module}\n'.format(
-                  output=output,
+                  output=escape_ninja_path(output),
                   action=action,
-                  input=module.full_path,
-                  deps=' | ' + ' '.join(deps) if deps else '',
-                  imports=imports,
+                  input=escape_ninja_path(module.full_path),
+                  deps=deps,
+                  imports=escape_ninja_path(imports),
                   module=module.name))
     return output
 
@@ -355,7 +378,7 @@ class PytypeRunner:
     k = '0' if self.keep_going else '1'
     # relpath() prevents possibly sensitive directory info from appearing in
     # ninja's "Entering directory" message.
-    c = os.path.relpath(os.path.dirname(self.ninja_file))
+    c = path_utils.relpath(path_utils.dirname(self.ninja_file))
     command = _get_executable('ninja') + [
         '-k', k, '-C', c, '-j', str(self.jobs)]
     if logging.getLogger().isEnabledFor(logging.INFO):
