@@ -704,7 +704,11 @@ class CallTracer(vm.VirtualMachine):
   def _check_return(self, node, actual, formal):
     if not self.ctx.options.report_errors:
       return True
-    match_result = self.ctx.matcher(node).compute_one_match(actual, formal)
+    if formal.full_name == "typing.TypeGuard":
+      expected = self.ctx.convert.bool_type
+    else:
+      expected = formal
+    match_result = self.ctx.matcher(node).compute_one_match(actual, expected)
     if not match_result.success:
       self.ctx.errorlog.bad_return_type(
           self.frames, node, match_result.bad_matches)
